ComplexMCARotator
=================

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexMCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexMCARotator.__init__
      ~ComplexMCARotator.components
      ~ComplexMCARotator.components_amplitude
      ~ComplexMCARotator.components_phase
      ~ComplexMCARotator.compute
      ~ComplexMCARotator.correlation_coefficients_X
      ~ComplexMCARotator.correlation_coefficients_Y
      ~ComplexMCARotator.covariance_fraction_CD95
      ~ComplexMCARotator.cross_correlation_coefficients
      ~ComplexMCARotator.deserialize
      ~ComplexMCARotator.fit
      ~ComplexMCARotator.fraction_variance_X_explained_by_X
      ~ComplexMCARotator.fraction_variance_Y_explained_by_X
      ~ComplexMCARotator.fraction_variance_Y_explained_by_Y
      ~ComplexMCARotator.get_params
      ~ComplexMCARotator.get_serialization_attrs
      ~ComplexMCARotator.heterogeneous_patterns
      ~ComplexMCARotator.homogeneous_patterns
      ~ComplexMCARotator.inverse_transform
      ~ComplexMCARotator.load
      ~ComplexMCARotator.predict
      ~ComplexMCARotator.save
      ~ComplexMCARotator.scores
      ~ComplexMCARotator.scores_amplitude
      ~ComplexMCARotator.scores_phase
      ~ComplexMCARotator.serialize
      ~ComplexMCARotator.squared_covariance_fraction
      ~ComplexMCARotator.transform
   
   

   
   
   